@@ -1,10 +1,9 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-import numpy as np
-
 import astropy.units as u
-from astropy.utils.data import get_pkg_data_filename
+import numpy as np
 from astropy.io import ascii
 from astropy.tests.helper import pytest
+from astropy.utils.data import get_pkg_data_filename
 
 from ..core import run_sampler, uniform_prior
 
@@ -13,7 +12,7 @@ fname = get_pkg_data_filename("data/CrabNebula_HESS_ipac.dat")
 data_table = ascii.read(fname)
 
 # Model definition
-def cutoffexp(pars, data):
+def cutoffexp(pars, input_data):
     """
     Powerlaw with exponential cutoff
 
@@ -24,6 +23,8 @@ def cutoffexp(pars, data):
         - 3: cutoff exponent (beta)
     """
 
+    data = input_data
+
     x = data["energy"].copy()
     # take logarithmic mean of first and last data points as normalization
     # energy
